# Software License
# 
# The majority of my software is published under a BSD-style license,
# given below.  Please check the specific package you downloaded to
# be sure that this license applies.
# 
# Copyright 2002, Chris Gonnerman
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions
# are met:
# 
# Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer. 
# 
# Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution. 
# 
# Neither the name of the author nor the names of any contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission. 
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""curses backend for anycons"""

import curses

_keymap = {
    'KEY_IC'    : 'ins',
    'KEY_DC'    : 'del',
    'KEY_NPAGE' : 'pgdn',
    'KEY_PPAGE' : 'pgup',
}

stdscr = None

def Init():
    global stdscr
    stdscr = curses.initscr()
    curses.noecho()
    curses.cbreak()
    stdscr.keypad(1)
    stdscr.clear()

def Close():
    global stdscr
    if not stdscr:
        return
    stdscr.clear()
    curses.nocbreak()
    stdscr.keypad(0)
    curses.echo()
    curses.endwin()
    stdscr = None

def Clear():
    if not stdscr:
        Init()
    stdscr.clear()

def Read():
    if not stdscr:
        Init()
    rc = stdscr.getkey()
    if _keymap.has_key(rc):
        return _keymap[rc]
    if rc[:6] == "KEY_F(":
        return "f" + rc[6:-1]
    if rc[:4] == "KEY_":
        return rc[4:].lower()
    return rc

def Write(s):
    if not stdscr:
        Init()
    stdscr.addstr(s)

def Goto(x, y):
    if not stdscr:
        Init()
    stdscr.move(y, x)

# end of file.
